@@ -17,12 +17,16 @@
 # Run manila's pre_test_hook.sh script first
 source $BASE/new/manila/contrib/ci/pre_test_hook.sh True dummy multibackend
 
+sudo -H pip install virtualenv
+virtualenv /tmp/devstack-tools
+/tmp/devstack-tools/bin/pip install -U devstack-tools==0.4.0
+
 localconf=$BASE/new/devstack/local.conf
+DSCONF=/tmp/devstack-tools/bin/dsconf
 
-echo "[[local|localrc]]" >> $localconf
 # Set big quota for share networks to avoid limit exceedances
-echo "MANILA_OPTGROUP_DEFAULT_quota_share_networks=50" >> $localconf
-
+$DSCONF setlc $localconf MANILA_OPTGROUP_DEFAULT_quota_share_networks 50
+$DSCONF setlc $localconf MANILA_CONFIGURE_DEFAULT_TYPES True
 # Enable and use only v3 of Identity API
-echo "IDENTITY_API_VERSION=3" >> $localconf
-echo "ENABLE_IDENTITY_V2=False" >> $localconf
+$DSCONF setlc $localconf IDENTITY_API_VERSION 3
+$DSCONF setlc $localconf ENABLE_IDENTITY_V2 False
