@@ -28,10 +28,10 @@ import copy
 
 from oslo_utils import strutils
 import six
-from six.moves.urllib import parse
 
 from manilaclient.common._i18n import _
 from manilaclient.common.apiclient import exceptions
+from manilaclient import utils
 
 
 def getid(obj):
@@ -339,7 +339,7 @@ class CrudManager(BaseManager):
         return self._list(
             '%(base_url)s%(query)s' % {
                 'base_url': self.build_url(base_url=base_url, **kwargs),
-                'query': '?%s' % parse.urlencode(kwargs) if kwargs else '',
+                'query': '?%s' % utils.safe_urlencode(kwargs) if kwargs else ''
             },
             self.collection_key)
 
@@ -378,7 +378,7 @@ class CrudManager(BaseManager):
         rl = self._list(
             '%(base_url)s%(query)s' % {
                 'base_url': self.build_url(base_url=base_url, **kwargs),
-                'query': '?%s' % parse.urlencode(kwargs) if kwargs else '',
+                'query': '?%s' % utils.safe_urlencode(kwargs) if kwargs else ''
             },
             self.collection_key)
         num = len(rl)
