@@ -146,9 +146,11 @@ class CreateShare(command.ShowOne):
         )
         parser.add_argument(
             '--public',
+            metavar='<public>',
             default=False,
             help=_('Level of visibility for share. '
-                   'Defines whether other tenants are able to see it or not.')
+                   'Defines whether other tenants are able to see it or not. '
+                   '(Default = False)')
         )
         parser.add_argument(
             '--share-type',
@@ -168,7 +170,7 @@ class CreateShare(command.ShowOne):
             metavar='<share-group>',
             default=None,
             help=_('Optional share group name or ID in which to create '
-                   'the share. (Experimental, Default=None).')
+                   'the share. (Default=None).')
         )
         return parser
 
@@ -441,8 +443,8 @@ class ListShare(command.Lister):
                                                 parsed_args.user,
                                                 parsed_args.user_domain).id
 
-        # set value of 'all_projects' when using project option
-        all_projects = bool(parsed_args.project) or parsed_args.all_projects
+        # set value of 'all_tenants' when using project option
+        all_tenants = bool(parsed_args.project) or parsed_args.all_projects
 
         share_type_id = None
         if parsed_args.share_type:
@@ -472,7 +474,7 @@ class ListShare(command.Lister):
                 parsed_args.share_server).id
 
         search_opts = {
-            'all_projects': all_projects,
+            'all_tenants': all_tenants,
             'is_public': parsed_args.public,
             'metadata': utils.extract_key_value_options(
                 parsed_args.property),
@@ -490,7 +492,6 @@ class ListShare(command.Lister):
             'project_id': project_id,
             'user_id': user_id,
             'offset': parsed_args.marker,
-            'limit': parsed_args.limit,
         }
 
         # NOTE(vkmc) We implemented sorting and filtering in manilaclient
@@ -543,3 +544,146 @@ class ShowShare(command.ShowOne):
         data.pop("shares_type", None)
 
         return self.dict2columns(data)
+
+
+class SetShare(command.Command):
+    """Set share properties."""
+    _description = _("Set share properties")
+
+    def get_parser(self, prog_name):
+        parser = super(SetShare, self).get_parser(prog_name)
+        parser.add_argument(
+            'share',
+            metavar="<share>",
+            help=_('Share to modify (name or ID)')
+        )
+        # 'metadata' --> 'properties'
+        parser.add_argument(
+            "--property",
+            metavar="<key=value>",
+            default={},
+            action=parseractions.KeyValueAction,
+            help=_("Set a property to this share "
+                   "(repeat option to set multiple properties)"),
+        )
+        parser.add_argument(
+            '--name',
+            metavar="<name>",
+            default=None,
+            help=_('New share name. (Default=None)')
+        )
+        parser.add_argument(
+            '--description',
+            metavar='<description>',
+            default=None,
+            help=_('New share description. (Default=None)')
+        )
+        parser.add_argument(
+            '--public',
+            metavar='<public>',
+            help=_('Level of visibility for share. '
+                   'Defines whether other tenants are able to see it or not. ')
+        )
+        return parser
+
+    def take_action(self, parsed_args):
+        share_client = self.app.client_manager.share
+        share_obj = apiutils.find_resource(share_client.shares,
+                                           parsed_args.share)
+        result = 0
+
+        if parsed_args.property:
+            try:
+                share_client.shares.set_metadata(
+                    share_obj.id, parsed_args.property)
+            except Exception as e:
+                LOG.error(_("Failed to set share properties "
+                            "'%(properties)s': %(exception)s"),
+                          {'properties': parsed_args.property,
+                           'exception': e})
+                result += 1
+
+        kwargs = {}
+        if parsed_args.name is not None:
+            kwargs['display_name'] = parsed_args.name
+        if parsed_args.description is not None:
+            kwargs['display_description'] = parsed_args.description
+        if parsed_args.public is not None:
+            kwargs['is_public'] = parsed_args.public
+        if kwargs:
+            try:
+                share_client.shares.update(share_obj.id, **kwargs)
+            except Exception as e:
+                LOG.error(_("Failed to update share display name, visibility "
+                          "or display description: %s"), e)
+                result += 1
+
+        if result > 0:
+            raise exceptions.CommandError(_("One or more of the "
+                                          "set operations failed"))
+
+
+class UnsetShare(command.Command):
+    """Unset share properties."""
+    _description = _("Unset share properties")
+
+    def get_parser(self, prog_name):
+        parser = super(UnsetShare, self).get_parser(prog_name)
+        parser.add_argument(
+            'share',
+            metavar="<share>",
+            help=_('Share to modify (name or ID)')
+        )
+        # 'metadata' --> 'properties'
+        parser.add_argument(
+            '--property',
+            metavar='<key>',
+            action='append',
+            help=_('Remove a property from share '
+                   '(repeat option to remove multiple properties)'),
+        )
+        parser.add_argument(
+            '--name',
+            action='store_true',
+            help=_('Unset share name.')
+        )
+        parser.add_argument(
+            '--description',
+            action='store_true',
+            help=_('Unset share description.')
+        )
+        return parser
+
+    def take_action(self, parsed_args):
+        share_client = self.app.client_manager.share
+        share_obj = apiutils.find_resource(share_client.shares,
+                                           parsed_args.share)
+        result = 0
+        kwargs = {}
+        if parsed_args.name:
+            kwargs['display_name'] = None
+        if parsed_args.description:
+            kwargs['display_description'] = None
+        if kwargs:
+            try:
+                share_client.shares.update(share_obj.id, **kwargs)
+            except Exception as e:
+                LOG.error(_("Failed to unset share display name "
+                            "or display description"), e)
+                result += 1
+
+        if parsed_args.property:
+            for key in parsed_args.property:
+                try:
+                    share_client.shares.delete_metadata(
+                        share_obj.id, [key])
+                except Exception as e:
+                    LOG.error(_("Failed to unset share property "
+                                "'%(key)s': %(e)s"),
+                              {'key': key, 'e': e})
+                    result += 1
+
+        if result > 0:
+            raise exceptions.CommandError(_(
+                "One or more of the "
+                "unset operations failed"))
