@@ -465,6 +465,12 @@ class OpenStackManilaShell(object):
         self.parser = self.get_subcommand_parser(
             os_api_version.get_major_version())
 
+        if argv and len(argv) > 1 and '--help' in argv:
+            argv = [x for x in argv if x != '--help']
+            if argv[0] in self.subcommands:
+                self.subcommands[argv[0]].print_help()
+                return False
+
         if options.help or not argv:
             self.parser.print_help()
             return False
@@ -699,10 +705,7 @@ def main():
         sys.exit(130)
     except Exception as e:
         logger.debug(e, exc_info=1)
-        message = e.message
-        if not isinstance(message, six.string_types):
-            message = str(message)
-        print("ERROR: %s" % encodeutils.safe_encode(message), file=sys.stderr)
+        print("ERROR: %s" % six.text_type(e), file=sys.stderr)
         sys.exit(1)
 
 
