@@ -15,6 +15,7 @@
 
 import argparse
 import mock
+import uuid
 
 from mock import call
 
@@ -288,7 +289,7 @@ class TestShareList(TestShare):
 
     def _get_search_opts(self):
         search_opts = {
-            'all_projects': False,
+            'all_tenants': False,
             'is_public': False,
             'metadata': {},
             'extra_specs': {},
@@ -320,7 +321,7 @@ class TestShareList(TestShare):
         cmd_columns, cmd_data = self.cmd.take_action(parsed_args)
 
         search_opts = {
-            'all_projects': False,
+            'all_tenants': False,
             'is_public': False,
             'metadata': {},
             'extra_specs': {},
@@ -363,7 +364,7 @@ class TestShareList(TestShare):
         cmd_columns, cmd_data = self.cmd.take_action(parsed_args)
 
         search_opts = {
-            'all_projects': False,
+            'all_tenants': False,
             'is_public': False,
             'metadata': {},
             'extra_specs': {},
@@ -382,7 +383,7 @@ class TestShareList(TestShare):
         }
 
         search_opts['project_id'] = self.project.id
-        search_opts['all_projects'] = True
+        search_opts['all_tenants'] = True
 
         self.shares_mock.list.assert_called_once_with(
             search_opts=search_opts,
@@ -411,7 +412,7 @@ class TestShareList(TestShare):
         cmd_columns, cmd_data = self.cmd.take_action(parsed_args)
 
         search_opts = {
-            'all_projects': False,
+            'all_tenants': False,
             'is_public': False,
             'metadata': {},
             'extra_specs': {},
@@ -430,7 +431,7 @@ class TestShareList(TestShare):
         }
 
         search_opts['project_id'] = self.project.id
-        search_opts['all_projects'] = True
+        search_opts['all_tenants'] = True
 
         self.shares_mock.list.assert_called_once_with(
             search_opts=search_opts,
@@ -457,7 +458,7 @@ class TestShareList(TestShare):
         cmd_columns, cmd_data = self.cmd.take_action(parsed_args)
 
         search_opts = {
-            'all_projects': False,
+            'all_tenants': False,
             'is_public': False,
             'metadata': {},
             'extra_specs': {},
@@ -503,7 +504,7 @@ class TestShareList(TestShare):
         cmd_columns, cmd_data = self.cmd.take_action(parsed_args)
 
         search_opts = {
-            'all_projects': False,
+            'all_tenants': False,
             'is_public': False,
             'metadata': {},
             'extra_specs': {},
@@ -548,7 +549,7 @@ class TestShareList(TestShare):
         cmd_columns, cmd_data = self.cmd.take_action(parsed_args)
 
         search_opts = {
-            'all_projects': False,
+            'all_tenants': False,
             'is_public': False,
             'metadata': {},
             'extra_specs': {},
@@ -593,7 +594,7 @@ class TestShareList(TestShare):
         cmd_columns, cmd_data = self.cmd.take_action(parsed_args)
 
         search_opts = {
-            'all_projects': False,
+            'all_tenants': False,
             'is_public': False,
             'metadata': {},
             'extra_specs': {},
@@ -623,7 +624,7 @@ class TestShareList(TestShare):
 
         self.assertEqual(data, tuple(cmd_data))
 
-    def test_share_list_all_projects(self):
+    def test_share_list_all_tenants(self):
         arglist = [
             '--all-projects',
         ]
@@ -638,7 +639,7 @@ class TestShareList(TestShare):
         cmd_columns, cmd_data = self.cmd.take_action(parsed_args)
 
         search_opts = {
-            'all_projects': False,
+            'all_tenants': False,
             'is_public': False,
             'metadata': {},
             'extra_specs': {},
@@ -656,7 +657,7 @@ class TestShareList(TestShare):
             'offset': None,
         }
 
-        search_opts['all_projects'] = True
+        search_opts['all_tenants'] = True
 
         self.shares_mock.list.assert_called_once_with(
             search_opts=search_opts,
@@ -682,7 +683,7 @@ class TestShareList(TestShare):
         cmd_columns, cmd_data = self.cmd.take_action(parsed_args)
 
         search_opts = {
-            'all_projects': False,
+            'all_tenants': False,
             'is_public': False,
             'metadata': {},
             'extra_specs': {},
@@ -789,7 +790,7 @@ class TestShareList(TestShare):
         self.assertEqual(self.columns, cmd_columns)
 
         search_opts = {
-            'all_projects': False,
+            'all_tenants': False,
             'is_public': False,
             'metadata': {},
             'extra_specs': {},
@@ -862,3 +863,148 @@ class TestShareShow(TestShare):
         self.assertEqual(
             manila_fakes.FakeShare.get_share_data(self._share),
             data)
+
+
+class TestShareSet(TestShare):
+
+    def setUp(self):
+        super(TestShareSet, self).setUp()
+
+        self._share = manila_fakes.FakeShare.create_one_share()
+        self.shares_mock.get.return_value = self._share
+
+        # Get the command object to test
+        self.cmd = osc_shares.SetShare(self.app, None)
+
+    def test_share_set_property(self):
+        arglist = [
+            '--property', 'Zorilla=manila',
+            self._share.id,
+        ]
+        verifylist = [
+            ('property', {'Zorilla': 'manila'}),
+            ('share', self._share.id)
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+        self.shares_mock.set_metadata.assert_called_with(
+            self._share.id,
+            {'Zorilla': 'manila'})
+
+    def test_share_set_name(self):
+        new_name = uuid.uuid4().hex
+        arglist = [
+            '--name', new_name,
+            self._share.id,
+        ]
+        verifylist = [
+            ('name', new_name),
+            ('share', self._share.id)
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+        self.shares_mock.update.assert_called_with(
+            self._share.id,
+            display_name=parsed_args.name)
+
+    def test_share_set_description(self):
+        new_description = uuid.uuid4().hex
+        arglist = [
+            '--description', new_description,
+            self._share.id,
+        ]
+        verifylist = [
+            ('description', new_description),
+            ('share', self._share.id)
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+        self.shares_mock.update.assert_called_with(
+            self._share.id,
+            display_description=parsed_args.description)
+
+    def test_share_set_visibility(self):
+        arglist = [
+            '--public', 'true',
+            self._share.id,
+        ]
+        verifylist = [
+            ('public', 'true'),
+            ('share', self._share.id)
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+        self.shares_mock.update.assert_called_with(
+            self._share.id,
+            is_public='true')
+
+
+class TestShareUnset(TestShare):
+
+    def setUp(self):
+        super(TestShareUnset, self).setUp()
+
+        self._share = manila_fakes.FakeShare.create_one_share()
+        self.shares_mock.get.return_value = self._share
+
+        # Get the command objects to test
+        self.cmd = osc_shares.UnsetShare(self.app, None)
+
+    def test_share_unset_property(self):
+        arglist = [
+            '--property', 'Manila',
+            self._share.id,
+        ]
+        verifylist = [
+            ('property', ['Manila']),
+            ('share', self._share.id)
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+        self.shares_mock.delete_metadata.assert_called_with(
+            self._share.id,
+            parsed_args.property)
+
+    def test_share_unset_name(self):
+        arglist = [
+            '--name',
+            self._share.id,
+        ]
+        verifylist = [
+            ('name', True),
+            ('share', self._share.id)
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+        self.shares_mock.update.assert_called_with(
+            self._share.id,
+            display_name=None)
+
+    def test_share_unset_description(self):
+        arglist = [
+            '--description',
+            self._share.id,
+        ]
+        verifylist = [
+            ('description', True),
+            ('share', self._share.id)
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+        self.shares_mock.update.assert_called_with(
+            self._share.id,
+            display_description=None)
