@@ -119,7 +119,7 @@ class OpenstackManilaShellTest(utils.TestCase):
                 tenant_id=env_vars['OS_PROJECT_ID'],
                 endpoint_type='publicURL',
                 extensions=mock.ANY,
-                service_type=constants.V1_SERVICE_TYPE,
+                service_type=constants.V2_SERVICE_TYPE,
                 service_name='',
                 retries=0,
                 http_log_debug=False,
@@ -191,7 +191,7 @@ class OpenstackManilaShellTest(utils.TestCase):
                 tenant_id="",
                 endpoint_type="publicURL",
                 extensions=mock.ANY,
-                service_type=constants.V1_SERVICE_TYPE,
+                service_type=constants.V2_SERVICE_TYPE,
                 service_name="",
                 retries=0,
                 http_log_debug=False,
@@ -270,7 +270,7 @@ class OpenstackManilaShellTest(utils.TestCase):
                 tenant_id="",
                 endpoint_type=expected["os_endpoint_type"],
                 extensions=mock.ANY,
-                service_type=constants.V1_SERVICE_TYPE,
+                service_type=constants.V2_SERVICE_TYPE,
                 service_name="",
                 retries=0,
                 http_log_debug=False,
@@ -290,12 +290,13 @@ class OpenstackManilaShellTest(utils.TestCase):
     def test_help_unknown_command(self):
         self.assertRaises(exceptions.CommandError, self.shell, 'help foofoo')
 
-    def test_help_on_subcommand(self):
+    @ddt.data('list --help', '--help list', 'help list')
+    def test_help_on_subcommand(self, cmd):
         required = [
             '.*?^usage: manila list',
             '.*?(?m)^List NAS shares with filters.',
         ]
-        help_text = self.shell('help list')
+        help_text = self.shell(cmd)
         for r in required:
             self.assertThat(help_text,
                             matchers.MatchesRegex(r, re.DOTALL | re.MULTILINE))
